function params = set_parameters()
%%SET_PARAMETERS 
% Set DPRF_tracker parameters according to the paper
    
%default settings
	 kernel_type = 'gaussian'; 
	 feature_type = 'hogcolor'; 

	%parameters according to the paper. at this point we can override
	%parameters based on the chosen kernel or feature type
	kernel.type = kernel_type;
	
	features.gray = false;
	features.hog = false;
	features.hogcolor = false;
        
	params.padding = 3;  %extra area surrounding the target
	params.lambda = 1e-4;  %regularization
	params.output_sigma_factor = 0.1;  %spatial bandwidth (proportional to target)
	params.scale_est_mode = 1; %a951106 predefined values: 0=no_scaling 1=our_scaling 2=RPT_scaling 3=GroundTruth-guided_scaling 4=affine_estimation_scaling
        
	switch feature_type
	case 'gray',
		interp_factor = 0.075;  %linear interpolation factor for adaptation

		kernel.sigma = 0.2;  %gaussian kernel bandwidth
		
		kernel.poly_a = 1;  %polynomial kernel additive term
		kernel.poly_b = 7;  %polynomial kernel exponent
	
		features.gray = true;
		cell_size = 1;
		
	case 'hog',
		interp_factor = 0.02;
		
		kernel.sigma = 0.5;
		
		kernel.poly_a = 1;
		kernel.poly_b = 9;
		
		features.hog = true;
		features.hog_orientations = 9;
		cell_size = 4;
    
    case 'hogcolor',
		interp_factor = 0.02; 
        		
		kernel.sigma = 0.5;
		
		kernel.poly_a = 1;
		kernel.poly_b = 9;
		
		features.hogcolor = true;
		features.hog_orientations = 9;
		cell_size = 4;
        
	otherwise
		error('Unknown feature.')
    end

params.kernel = kernel;    
params.interp_factor = interp_factor;
params.cell_size = cell_size;
params.features = features;
params.visualization = false;
 
end

