function [state, location, params] = tracker_DPRF_initialize(im, region, params)

    gray = double(rgb2gray(im));

    [height, width] = size(gray);

    % If the provided region is a polygon ...
    if numel(region) > 4
        x1 = round(min(region(1:2:end)));
        x2 = round(max(region(1:2:end)));
        y1 = round(min(region(2:2:end)));
        y2 = round(max(region(2:2:end)));
        region = round([x1, y1, x2 - x1, y2 - y1]);
    else
        region = round([round(region(1)), round(region(2)), ... 
        round(region(1) + region(3)) - round(region(1)), ...
        round(region(2) + region(4)) - round(region(2))]);
    end;

    x1 = max(0, region(1));
    y1 = max(0, region(2));
    x2 = min(width-1, region(1) + region(3) - 1);
    y2 = min(height-1, region(2) + region(4) - 1);

    template = gray((y1:y2)+1, (x1:x2)+1);

    state = struct('template', template, 'size', [x2 - x1 + 1, y2 - y1 + 1]);
    state.window = max(state.size) * 2;
    state.position = [x1 + x2 + 1, y1 + y2 + 1] / 2;

    location = [x1, y1, state.size];

    if state.size(1)<16, state.size(1)=16;end 
    if state.size(2)<16, state.size(2)=16;end 
    
    target_sz = state.size([2,1]); 
    pos = state.position([2,1]); 
    
    params.init_pos = pos; 
    params.wsize = target_sz; 

    randn('seed',0);rand('seed',0);
    
    params.PSRange = 0.6/(1 + params.padding);
    params.deleteThresholdP =5;
    params.deleteThresholdN =15;
    params.numParticles = 9;
    params.yellowArea = 1.5;
    params.blueArea = 9;
    
    
%   %if the target is large, lower the resolution, we don't need that much
% 	%detail
% 	resize_image = (sqrt(prod(target_sz)) >= 100);  %diagonal size >= threshold
% 	if resize_image,
% 		pos = floor(pos / 2);
% 		target_sz = floor(target_sz / 2);
%     end
%     
% 	if show_visualization,  %create video interface
% 		update_visualization = show_video(img_files, video_path, resize_image);
%     end
    
    %% 
	state.changed = 1;
    state.scale_factor = [1,1]; 
    temp = load('w2crs');  
    state.w2c = temp.w2crs;  
    params.max_disp_init = 7; % in pexels: 7*cell_size=28 in each directions
    
%%

%initialize parts
state.frame = 1; %avot2017

                pars = repmat([pos target_sz*0.6]',[1 params.numParticles]); 
                state.contexts = addParts(im,pars,pos,target_sz,params);
                state.weights = repmat(1/numel(state.contexts), [1 numel(state.contexts)])' ; %importance weights associated to each patch 
                state.weightSet = state.weights'; 
                for i=1:numel(state.contexts) 
                    state.pos_ref(i,:) = state.contexts{i}.pos;
                end

            points=[];
            n=numel(state.contexts);
            for i=1:n
                if state.contexts{i}.target
                    p = state.contexts{i}.pos;
                    points = [points; p];
                    state.contexts{i}.displace = pos -p;
                end
            end
            state.original = target_sz;
            params.his=[];

            state.area = prod(std(points));

        
        %track the parts
        patch_num = numel(state.contexts);
        for i=1:patch_num 
            state.contexts{i}.bi_weight = (state.weights(i)>=0.02);
            state.contexts{i} = kcftracker(im, state.contexts{i}, params, pos, state.scale_factor, state.w2c); 
        end
               
        
    state.pos = floor(params.init_pos);
    state.target_sz = floor(params.wsize);


end
